part of '../../gitea.dart';

/// Represents a repository.
@JsonSerializable(explicitToJson: true, fieldRename: FieldRename.snake)
class Repository {

  /// Creates a new repository.
  Repository(this.id, this.fullName);

  /// Creates a new repository from the specified [map] in JSON format.
  factory Repository.fromJson(Map<String, dynamic> map) => _$RepositoryFromJson(map);

  /// The repository name.
  String _name = '';

  /// The HTTP-based URL for cloning this repository.
  Uri cloneUrl;

  /// The date the repository was created.
  DateTime createdAt;

  /// The name of the default branch.
  @JsonKey(defaultValue: '')
  String defaultBranch = '';

  /// The repository description.
  @JsonKey(defaultValue: '')
  String description = '';

  /// The number of forks of this repository.
  @JsonKey(defaultValue: 0)
  int forksCount = 0;

  /// The full name.
  @JsonKey(defaultValue: '')
  String fullName;

  /// The Gitea URL of this repository.
  Uri htmlUrl;

  /// The repository identifier.
  @JsonKey(defaultValue: -1)
  final int id;

  /// Value indicating whether this repository is empty.
  @JsonKey(defaultValue: true, name: 'empty')
  bool isEmpty = true;

  /// Value indicating whether this repository is a fork.
  @JsonKey(defaultValue: false, name: 'fork')
  bool isFork = false;

  /// Value indicating whether this repository is a mirror.
  @JsonKey(defaultValue: false, name: 'mirror')
  bool isMirror = false;

  /// Value indicating whether this repository is private.
  @JsonKey(defaultValue: false, name: 'private')
  bool isPrivate = false;

  /// The repository name.
  @JsonKey(defaultValue: '')
  String get name {
    if (_name.isNotEmpty) return _name;
    return fullName.isNotEmpty ? fullName.split('/').last : '';
  }

  set name(String value) => _name = value;

  /// The number of open issues of this repository.
  @JsonKey(defaultValue: 0)
  int openIssuesCount = 0;

  /// The repository owner.
  User owner;

  /// The parent repository, if this repository is a fork or a mirror.
  Repository parent;

  /// The repository permissions.
  Permission permissions;

  /// The repository size, in kilobytes.
  int size = 0;

  /// The SSH-based URL for cloning this repository.
  Uri sshUrl;

  /// The number of stars of this repository.
  @JsonKey(defaultValue: 0)
  int starsCount = 0;

  /// The date the repository was updated.
  DateTime updatedAt;

  /// The number of watchers of this repository.
  @JsonKey(defaultValue: 0)
  int watchersCount = 0;

  /// The URL of the repository website.
  Uri website;

  /// Converts this object to a [Map] in JSON format.
  Map<String, dynamic> toJson() => _$RepositoryToJson(this);

  /// Returns a string representation of this object.
  @override
  String toString() => 'Repository ${json.encode(this)}';
}
