part of '../../gitea.dart';

/// Represents a Gitea user.
@JsonSerializable(fieldRename: FieldRename.snake)
class User {

  /// Creates a new user.
  User(this.id, this.login);

  /// Creates a new user from the specified [map] in JSON format.
  factory User.fromJson(Map<String, dynamic> map) => _$UserFromJson(map);

  /// The URL to the user's avatar.
  Uri avatarUrl;

  /// The mail address.
  @JsonKey(defaultValue: '')
  String email = '';

  /// The full name.
  @JsonKey(defaultValue: '')
  String fullName = '';

  /// The user identifier.
  @JsonKey(defaultValue: -1)
  final int id;

  /// The user locale.
  @JsonKey(defaultValue: '')
  String language = '';

  /// The name of the Gitea account.
  @JsonKey(defaultValue: '')
  String login;

  /// Converts this object to a [Map] in JSON format.
  Map<String, dynamic> toJson() => _$UserToJson(this);

  /// Returns a string representation of this object.
  @override
  String toString() => 'User ${json.encode(this)}';
}
