part of '../gitea.dart';

/// Represents a Gitea push event.
@JsonSerializable(explicitToJson: true, fieldRename: FieldRename.snake)
class PushEvent {

  /// Creates a new permission.
  PushEvent();

  /// Creates a new permission from the specified [map] in JSON format.
  factory PushEvent.fromJson(Map<String, dynamic> map) => _$PushEventFromJson(map);

  /// The hash of the new Git revision.
  @JsonKey(defaultValue: '')
  String after = '';

  /// The hash of the previous Git revision.
  @JsonKey(defaultValue: '')
  String before = '';

  /// The revision commits.
  @JsonKey(defaultValue: [])
  List<PayloadCommit> commits = [];

  /// The URL for comparing the revisions.
  Uri compareUrl;

  /// The user who pushed the commits.
  User pusher;

  /// The Git reference.
  @JsonKey(defaultValue: '')
  String ref = '';

  /// The repository where the commits were pushed.
  Repository repository;

  /// The secret used to validate this event.
  @JsonKey(defaultValue: '')
  String secret = '';

  /// The user who sent this event.
  User sender;

  /// Converts this object to a [Map] in JSON format.
  Map<String, dynamic> toJson() => _$PushEventToJson(this);

  /// Returns a string representation of this object.
  @override
  String toString() => 'PushEvent ${json.encode(this)}';
}
