part of '../../gitea.dart';

/// Represents a commit.
@JsonSerializable(explicitToJson: true)
class PayloadCommit {

  /// Creates a new payload commit.
  PayloadCommit(this.id, [this.message = '']);

  /// Creates a new payload commit from the specified [map] in JSON format.
  factory PayloadCommit.fromJson(Map<String, dynamic> map) => _$PayloadCommitFromJson(map);

  /// The person who authored the commit.
  PayloadUser author;

  /// The person who committed the code.
  PayloadUser committer;

  /// The commit hash.
  @JsonKey(defaultValue: '')
  final String id;

  /// The commit message.
  @JsonKey(defaultValue: '')
  String message;

  /// The commit date.
  DateTime timestamp;

  /// The URL to the commit's history.
  Uri url;

  /// The GPG verification of this commit.
  PayloadCommitVerification verification;

  /// Converts this object to a [Map] in JSON format.
  Map<String, dynamic> toJson() => _$PayloadCommitToJson(this);

  /// Returns a string representation of this object.
  @override
  String toString() => 'PayloadCommit ${json.encode(this)}';
}
